package com.zswl.cloud.springBtach.server.core.controller;

import com.github.microservice.auth.client.constant.AuthConstant;
import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.security.annotations.ResourceAuth;
import com.github.microservice.auth.security.helper.AuthHelper;
import com.github.microservice.auth.security.type.AuthType;
import com.zhongshu.payment.client.model.Pages;
import com.zhongshu.payment.client.model.order.AdminSeachOrderModel;
import com.zhongshu.payment.client.model.order.OrderResultModel;
import com.zhongshu.payment.client.model.order.ScanModel;
import com.zhongshu.payment.client.model.order.UserSeachOrderModel;
import com.zhongshu.payment.client.model.order.v2.OrderResult2Model;
import com.zhongshu.payment.client.model.order.v2.UserSeachOrder2Model;
import com.zhongshu.payment.client.model.payment.CreateResponseModel;
import com.zhongshu.payment.client.service.v2.OrderService2;
import com.zswl.cloud.springBtach.server.core.service.OrderServiceImp;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.http.MediaType;
import org.springframework.util.Assert;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

@Log4j2
@RestController
@RequestMapping("order")
public class OrderController {


    @Autowired
    AuthHelper authHelper;

    @Autowired
    OrderServiceImp orderServiceImp;


    @ApiOperation("生成二维码")
    @ResourceAuth(value = AuthConstant.User, type = AuthType.User)
    @RequestMapping(value = "qrCode/{id}", method = RequestMethod.GET, consumes = {MediaType.ALL_VALUE})
    public ResultContent<String> qrCode(@PathVariable("id") String id) {
        Assert.hasText(id, "id不能为空");
        return orderServiceImp.qrCode(id);
    }


    @ApiOperation("商家验券")
    @ResourceAuth(value = "checkCoupon", type = AuthType.Enterprise)
    @ResourceAuth(value = "checkCoupon", type = AuthType.Project)
    @RequestMapping(value = "shop/verification/{token}", method = RequestMethod.GET, consumes = {MediaType.ALL_VALUE})
    public ResultContent verification(@PathVariable("token") String token) {

        Assert.hasText(token, "token不能为空");
        return orderServiceImp.verification(token);
    }


    @ApiOperation("app订单查询")
    @RequestMapping(value = "user/search", method = RequestMethod.POST)
    @ResourceAuth(value = AuthConstant.User, type = AuthType.User)
    public ResultContent<Page<OrderResultModel>> userSearch(@RequestBody UserSeachOrder2Model userSeachOrderModel) {

        return orderServiceImp.userSearch(userSeachOrderModel, page(userSeachOrderModel));
    }

    @ApiOperation("app订单详情")
    @RequestMapping(value = "user/userDetails/{id}", method = RequestMethod.GET)
    @ResourceAuth(value = AuthConstant.User, type = AuthType.User)
    public ResultContent<OrderResultModel> userDetails(@PathVariable("id") String id) {

        return orderServiceImp.userDetails(id);
    }



    /*                                                 商家接口                                                 */


    @ApiOperation("商家_订单查询列表")
    @RequestMapping(value = "shop/search", method = RequestMethod.POST)
    @ResourceAuth(value = "admin", type = AuthType.Enterprise)
    @ResourceAuth(value = "admin", type = AuthType.Project)
    public ResultContent<Page<OrderResult2Model>> shopSearch(@RequestBody AdminSeachOrderModel seachOrderModel) {
        return orderServiceImp.shopSearch(seachOrderModel, page(seachOrderModel));
    }


    // 平台接口

    @ApiOperation("平台_订单查询")
    @RequestMapping(value = "platform/search", method = RequestMethod.POST)
    @ResourceAuth(value = AuthConstant.SuperAdmin, type = AuthType.Platform)
    public ResultContent<Page<OrderResult2Model>> platformSearch(@RequestBody AdminSeachOrderModel seachOrderModel) {

        return orderServiceImp.adminSearch(seachOrderModel, page(seachOrderModel));
    }

    private Pageable page(Pages page) {
        try {

            return PageRequest.of(page.getPage(), page.getSize());
        } catch (Exception e) {

            log.info("PageUtile.page异常：{}", e.getMessage());

        }
        return PageRequest.of(0, 20);


    }


}
